#!perl

# --8<--8<--8<--8<--
#
# Copyright (C) 2008 Smithsonian Astrophysical Observatory
#
# This file is part of App::Env::SAOTrace
#
# App::Env::SAOTrace is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# -->8-->8-->8-->8--

package App::Env::SAOTrace;

use strict;
use warnings;

use Carp;
use File::Spec;
use Shell::GetEnv;
use Params::Validate qw( validate_with );

our $VERSION = '0.10';

## no critic ( ProhibitAccessOfPrivateData )

=pod

=begin making_pod_coverage_shut_up

=item envs

=end making_pod_coverage_shut_up

=cut

sub envs {

    my %opt = validate_with
      ( params => @_, 
        spec => {
                 root => { default => exists $ENV{APP_ENV_SAOTRACE_ROOT}
                           ? $ENV{APP_ENV_SAOTRACE_ROOT} : '%SAOTRACE_ROOT%' },
                 db   => { default => exists $ENV{APP_ENV_SAOTRACE_DB}
                           ? $ENV{APP_ENV_SAOTRACE_DB} : '%SAOTRACE_DB%' },
                 version => 0,
                },
        normalize_keys => sub { return lc $_[0] },
      );

    $opt{root} .= '-' . $opt{version} if exists $opt{version};

    my $script = File::Spec->catfile( $opt{root}, 'bin', 'saotrace_setup.sh' );
    croak( "SAOTrace startup script $script does not exist\n" )
      unless -f $script;

    return Shell::GetEnv->new( 'sh',
                               "SAOTRACE_ROOT='$opt{root}'",
                               'export SAOTRACE_ROOT',
                               "SAOTRACE_DB='$opt{db}'",
                               'export SAOTRACE_DB',
                               ". $script" )->envs;
}

1;

__END__

=head1 NAME

App::Env::SAOTrace - retrieve the SAOTrace environment


=head1 SYNOPSIS

    use App::Env qw( SAOTrace );


=head1 DESCRIPTION

This module should not be used directly; see B<App::Env>.  It uses the
F<saotrace_setup.sh> script to generate the environment used to run
SAOTrace software.


=head2 Initialization script

The absolute path of the F<saotrace_setup.sh> is generated from the
template

  SAOTRACE_ROOT/bin/saotrace_setup.sh


B<SAOTRACE_ROOT> is set to the first available value from the following list:

=over

=item The value of the C<root> option, if present

=item The value of the C<APP_ENV_SAOTRACE_ROOT> environmental variable if present

=item The default value of %SAOTRACE_ROOT%

=back

If the C<version> option is specified in the B<AppOpts> hash,  B<SAOTRACE_ROOT>
is modified to be

  SAOTRACE_ROOT-VERSION

=head2 Environment Variables

The following variables are also added to the environment:


=over

=item SAOTRACE_ROOT

The value as described above.

=item SAOTRACE_DB

The first available value from the following list:

=over

=item The value of the C<db> option, if present

=item The value of the C<APP_ENV_SAOTRACE_DB> environmental variable if present

=item The default value of %SAOTRACE_DB%

=back

=back

=head2 Available Options

The following options are recognized when passed via the B<AppOpts>
hash (see B<App::Env> for more information):

=over

=item root I<directory name>

The root directory of the SAOTrace software installation.  See above for how this is used.

=item db I<directory name>

The root directory of the SAOTrace model database installation.  This
is I<not> the same as the software installation.

=item version I<string>

The version of SAOTrace.  See above for how this is used.

=back

=head1 SEE ALSO

B<App::Env>.

=head1 VERSION

Version 0.10

=head1 LICENSE AND COPYRIGHT

Copyright (c) 2008 The Smithsonian Astrophysical Observatory

App::Env::SAOTrace is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

=head1 AUTHOR

Diab Jerius  E<lt>djerius@cpan.orgE<gt>


